@@ -16,13 +16,7 @@
 
 #undef NO_FCNTL_LOCK
 #undef NON_FREE
-#undef ENABLE_NLS
-#undef HAVE_CATGETS
 
-
-#undef HAVE_GETTEXT
-#undef HAVE_LC_MESSAGES
-#undef HAVE_STPCPY
 #undef REQUEST_CAPABILITIES
 
 #undef LIBMCRYPT24
