@@ -109,7 +109,7 @@
 
 #define DEFAULT_MODE "cbc"
 #define DEFAULT_KEYMODE "mcrypt-sha1"
-#define HASH_ALGORITHM "crc32"
+#define HASH_ALGORITHM "sha1"
 
 #define ENCRYPT 0
 #define DECRYPT 1
