@@ -1,5 +1,12 @@
 #define MAX_KEY_LEN 513
 
+#define rotl32(x,n)   (((x) << ((word32)(n))) | ((x) >> (32 - (word32)(n))))
+#define rotr32(x,n)   (((x) >> ((word32)(n))) | ((x) << (32 - (word32)(n))))
+#define rotl16(x,n)   (((x) << ((word16)(n))) | ((x) >> (16 - (word16)(n))))
+#define rotr16(x,n)   (((x) >> ((word16)(n))) | ((x) << (16 - (word16)(n))))
+#define byteswap32(x)     ((rotl32(x, 8) & 0x00ff00ff) | (rotr32(x, 8) & 0xff00ff00))
+#define byteswap16(x)  ((rotl16(x, 8) & 0x00ff) | (rotr16(x, 8) & 0xff00))
+
 char * get_password(int numofchar, int mode, unsigned int *len, void * salt);
 int show_mode(int ende, int stype,int smode,char *output,int bitmode);
 char** read_key_file(char * file, int* num);
