@@ -1,24 +1,18 @@
-#ifndef DEFINES_H
- #define DEFINES_H
- #include <defines.h>
-#endif
-
 void time_out(int signo);
 
-#ifdef HAVE_UNISTD_H
-# ifdef HAVE_FCNTL
+#ifndef NO_FCNTL_LOCK
 struct flock* file_lock(short type, short whence);
 int read_lock(int fd);
 int write_lock(int fd);
 int append_lock(int fd);
 void unlock(int fd);  /* unlock */
 
-# else /* Do nothing */
+#else /* Do nothing */
+
 void file_lock(short type, short whence);
 int read_lock(int fd);
 int write_lock(int fd);
 int append_lock(int fd);
 void unlock(int fd);
 
-# endif
-#endif
+#endif /* NO_FCNTL_LOCK */
